pub struct SqlBuilder<'config> { /* private fields */ }Expand description
AST builder for SQL.
This builder is responsible for converting the generic syntax tree (green/red trees)
into a strongly-typed SQL Abstract Syntax Tree (AST). It implements the Builder
trait, allowing it to be used within the Oak incremental parsing framework.
Usage
use oak_core::{Builder, source::SourceText};
use oak_sql::{SqlBuilder, SqlLanguage};
let config = SqlLanguage::default();
let builder = SqlBuilder::new(&config);
// ... use builder to build AST from sourceImplementations
Sourceimpl<'config> SqlBuilder<'config>
impl<'config> SqlBuilder<'config>
Sourcepub fn new(config: &'config SqlLanguage) -> Self
pub fn new(config: &'config SqlLanguage) -> Self
Creates a new SqlBuilder with the specified language configuration.