SqlTokenType

Enum SqlTokenType 

pub enum SqlTokenType {
Show 171 variants Root, ExplainStatement, TransactionStatement, PragmaStatement, ShowStatement, SelectStatement, InsertStatement, UpdateStatement, DeleteStatement, CreateStatement, DropStatement, AlterStatement, Expression, Identifier, TableName, ColumnName, JoinClause, GroupByClause, HavingClause, OrderByClause, LimitClause, SelectItem, Alias, ColumnDefinition, ValueList, Assignment, AlterAction, ErrorNode, Whitespace, Newline, Comment, LineComment, BlockComment, NumberLiteral, FloatLiteral, StringLiteral, BooleanLiteral, NullLiteral, Identifier_, Select, From, Where, Insert, Into, Values, Update, Set, Delete, Create, Table, Drop, Alter, Add, Column, Primary, Key, Foreign, References, Index, Unique, Not, Null, Default, AutoIncrement, And, Or, In, Like, Between, Is, As, Join, Inner, Left, Right, Full, Outer, On, Group, By, Having, Order, Asc, Desc, Limit, Offset, Union, All, Distinct, Count, Sum, Avg, Min, Max, Explain, Pragma, Show, View, Database, Schema, True, False, Exists, Trigger, After, Delimiter, For, Each, Row, Check, Rename, To, Case, When, Then, Else, End, If, Begin, Commit, Rollback, Transaction, Conflict, Do, Nothing, Returning, Vector, Ilike, Strict, Without, Rowid, Int, Integer, Varchar, Char, Text, Date, Time, Timestamp, Decimal, Float, Double, Boolean, Serial, BigSerial, Plus, Minus, Star, Slash, Percent, Equal, NotEqual, Less, Greater, LessEqual, GreaterEqual, Concat, DoubleColon, LeftParen, RightParen, LeftBracket, RightBracket, LeftBrace, RightBrace, Comma, Semicolon, Dot, Colon, Question, Error, Eof,
}
Token types for the SQL language.

Variants



Root

Root node.



ExplainStatement

EXPLAIN statement.



TransactionStatement

TRANSACTION statement.



PragmaStatement

PRAGMA statement.



ShowStatement

SHOW statement.



SelectStatement

SELECT statement.



InsertStatement

INSERT statement.



UpdateStatement

UPDATE statement.



DeleteStatement

DELETE statement.



CreateStatement

CREATE statement.



DropStatement

DROP statement.



AlterStatement

ALTER statement.



Expression

SQL expression.



Identifier

Identifier.



TableName

Table name.



ColumnName

Column name.



JoinClause

JOIN clause.



GroupByClause

GROUP BY clause.



HavingClause

HAVING clause.



OrderByClause

ORDER BY clause.



LimitClause

LIMIT clause.



SelectItem

Select item.



Alias

Alias.



ColumnDefinition

Column definition.



ValueList

Value list.



Assignment

Assignment.



AlterAction

Alter action.



ErrorNode

Error node.



Whitespace

Whitespace.



Newline

Newline.



Comment

Comment.



LineComment

Line comment.



BlockComment

Block comment.



NumberLiteral

Number literal.



FloatLiteral

Float literal.



StringLiteral

String literal.



BooleanLiteral

Boolean literal.



NullLiteral

NULL literal.



Identifier_

Identifier token.



Select

SELECT keyword.



From

FROM keyword.



Where

WHERE keyword.



Insert

INSERT keyword.



Into

INTO keyword.



Values

VALUES keyword.



Update

UPDATE keyword.



Set

SET keyword.



Delete

DELETE keyword.



Create

CREATE keyword.



Table

TABLE keyword.



Drop

DROP keyword.



Alter

ALTER keyword.



Add

ADD keyword.



Column

COLUMN keyword.



Primary

PRIMARY keyword.



Key

KEY keyword.



Foreign

FOREIGN keyword.



References

REFERENCES keyword.



Index

INDEX keyword.



Unique

UNIQUE keyword.



Not

NOT keyword.



Null

NULL keyword.



Default

DEFAULT keyword.



AutoIncrement

AUTO_INCREMENT keyword.



And

AND keyword.



Or

OR keyword.



In

IN keyword.



Like

LIKE keyword.



Between

BETWEEN keyword.



Is

IS keyword.



As

AS keyword.



Join

JOIN keyword.



Inner

INNER keyword.



Left

LEFT keyword.



Right

RIGHT keyword.



Full

FULL keyword.



Outer

OUTER keyword.



On

ON keyword.



Group

GROUP keyword.



By

BY keyword.



Having

HAVING keyword.



Order

ORDER keyword.



Asc

ASC keyword.



Desc

DESC keyword.



Limit

LIMIT keyword.



Offset

OFFSET keyword.



Union

UNION keyword.



All

ALL keyword.



Distinct

DISTINCT keyword.



Count

COUNT keyword.



Sum

SUM keyword.



Avg

AVG keyword.



Min

MIN keyword.



Max

MAX keyword.



Explain

EXPLAIN keyword.



Pragma

PRAGMA keyword.



Show

SHOW keyword.



View

VIEW keyword.



Database

DATABASE keyword.



Schema

SCHEMA keyword.



True

TRUE keyword.



False

FALSE keyword.



Exists

EXISTS keyword.



Trigger

TRIGGER keyword.



After

AFTER keyword.



Delimiter

DELIMITER keyword.



For

FOR keyword.



Each

EACH keyword.



Row

ROW keyword.



Check

CHECK keyword.



Rename

RENAME keyword.



To

TO keyword.



Case

CASE keyword.



When

WHEN keyword.



Then

THEN keyword.



Else

ELSE keyword.



End

END keyword.



If

IF keyword.



Begin

BEGIN keyword.



Commit

COMMIT keyword.



Rollback

ROLLBACK keyword.



Transaction

TRANSACTION keyword.



Conflict

CONFLICT keyword.



Do

DO keyword.



Nothing

NOTHING keyword.



Returning

RETURNING keyword.



Vector

VECTOR keyword.



Ilike

ILIKE keyword.



Strict

STRICT keyword.



Without

WITHOUT keyword.



Rowid

ROWID keyword.



Int

INT type.



Integer

INTEGER type.



Varchar

VARCHAR type.



Char

CHAR type.



Text

TEXT type.



Date

DATE type.



Time

TIME type.



Timestamp

TIMESTAMP type.



Decimal

DECIMAL type.



Float

FLOAT type.



Double

DOUBLE type.



Boolean

BOOLEAN type.



Serial

SERIAL type.



BigSerial

BIGSERIAL type.



Plus

Plus operator +.



Minus

Minus operator -.



Star

Multiplication operator *.



Slash

Division operator /.



Percent

Modulo operator %.



Equal

Equality operator =.



NotEqual

Inequality operator <>.



Less

Less than operator <.



Greater

Greater than operator >.



LessEqual

Less than or equal operator <=.



GreaterEqual

Greater than or equal operator >=.



Concat

Concatenation operator ||.



DoubleColon

Double Colon ::.



LeftParen

Left parenthesis (.



RightParen

Right parenthesis ).



LeftBracket

Left bracket [.



RightBracket

Right bracket ].



LeftBrace

Left brace {.



RightBrace

Right brace }.



Comma

Comma ,.



Semicolon

Semicolon ;.



Dot

Dot ..



Colon

Colon :.



Question

Question mark ?.



Error

Error token.



Eof

End of stream.